package com.zd.chemical.service;

import java.util.List;
import java.util.Map;

import com.zd.chemical.domain.HxpCabinet;
import com.zd.chemical.domain.vo.*;
import com.zd.system.api.laboratory.CabinetV2Lock;

/**
 * 化学品机柜管理信息Service接口
 *
 * @author liubo
 * @date 2022-06-16
 */
public interface IHxpCabinetService
{
    /**
     * 查询化学品机柜管理信息
     *
     * @param id 化学品机柜管理信息主键
     * @return 化学品机柜管理信息
     */
    public HxpCabinet selectHxpCabinetById(Long id);

    /**
     * 查询化学品机柜管理信息列表
     *
     * @param hxpCabinetSearch 化学品机柜管理信息
     * @return 化学品机柜管理信息集合
     */
    public List<HxpCabinetVo> selectHxpCabinetList(HxpCabinetSearch hxpCabinetSearch);

    /**
     * 新增化学品机柜管理信息
     *
     * @param hxpCabinet 化学品机柜管理信息
     * @return 结果
     */
    public int insertHxpCabinet(HxpCabinet hxpCabinet);

    /**
     * 修改化学品机柜管理信息
     *
     * @param hxpCabinet 化学品机柜管理信息
     * @return 结果
     */
    public int updateHxpCabinet(HxpCabinet hxpCabinet);

    /**
     * 批量删除化学品机柜管理信息
     *
     * @param ids 需要删除的化学品机柜管理信息主键集合
     * @return 结果
     */
    public int deleteHxpCabinetByIds(Long[] ids);

    /**
     * 删除化学品机柜管理信息信息
     *
     * @param id 化学品机柜管理信息主键
     * @return 结果
     */
    public int deleteHxpCabinetById(Long id);


    /**
     * 查询机柜关联化学品数据统计列表
     *
     * @param hxpCabinetSearch 化学品机柜管理信息
     * @return 化学品机柜管理信息集合
     */
    public List<HxpCabinetInclusionChemicalVo> getCabinetByChemical(HxpCabinetSearch hxpCabinetSearch);

    List<AioCabinetLockVo> queryCabinetLockList(AioCabinetLockVo aioCabinetLockVo);

    AioSubInfoVo querySubInfo(Long subId);

    CabinetV2Lock openLock(AioCabinetLockVo aioCabinetLockVo);

    CabinetV2Lock closeLock(AioCabinetLockVo aioCabinetLockVo);
}
